@@ -326,6 +326,25 @@ export const buildGalleryMenuOptions = (selectedImages, readOnly, metadataStatus
       });
     }
 
+    if (isSomeone !== null && !readOnly) {
+      const { canRemovePhotoFromPeople, canAddPhotoToPeople } = faceRecognitionPermission;
+      if (menuOptions.length > 0) {
+        menuOptions.push('Divider');
+      }
+      if (isSomeone && canRemovePhotoFromPeople) {
+        menuOptions.push({
+          key: TextTranslation.REMOVE_FROM_GROUP.key,
+          value: TextTranslation.REMOVE_FROM_GROUP.value
+        });
+      }
+      if (!isSomeone && canAddPhotoToPeople) {
+        menuOptions.push({
+          key: TextTranslation.ADD_TO_GROUPS.key,
+          value: TextTranslation.ADD_TO_GROUPS.value
+        });
+      }
+    }
+
     return menuOptions;
   }
 
@@ -375,18 +394,18 @@ export const buildGalleryMenuOptions = (selectedImages, readOnly, metadataStatus
     });
   }
 
-  if (isSomeone && !readOnly) {
+  if (isSomeone !== undefined && !readOnly) {
     menuOptions.push('Divider');
 
     const { canRemovePhotoFromPeople, canAddPhotoToPeople, canSetPeoplePhoto } = faceRecognitionPermission;
-    if (canRemovePhotoFromPeople) {
+    if (isSomeone && canRemovePhotoFromPeople) {
       menuOptions.push({
         key: TextTranslation.REMOVE_FROM_GROUP.key,
         value: TextTranslation.REMOVE_FROM_GROUP.value
       });
     }
 
-    if (canAddPhotoToPeople) {
+    if (!isSomeone && canAddPhotoToPeople) {
       menuOptions.push({
         key: TextTranslation.ADD_TO_GROUPS.key,
         value: TextTranslation.ADD_TO_GROUPS.value
@@ -403,7 +422,7 @@ export const buildGalleryMenuOptions = (selectedImages, readOnly, metadataStatus
   return menuOptions;
 };
 
-export const buildGalleryToolbarMenuOptions = (selectedImages, readOnly, metadataStatus, isSomeone = false, faceRecognitionPermission = {}) => {
+export const buildGalleryToolbarMenuOptions = (selectedImages, readOnly, metadataStatus, isSomeone, faceRecognitionPermission = {}) => {
   if (!selectedImages || selectedImages.length === 0) {
     return [];
   }
@@ -420,6 +439,25 @@ export const buildGalleryToolbarMenuOptions = (selectedImages, readOnly, metadat
         subOpList: aiOptions
       });
     }
+
+    if (isSomeone !== null && !readOnly) {
+      const { canRemovePhotoFromPeople, canAddPhotoToPeople } = faceRecognitionPermission;
+      if (menuOptions.length > 0) {
+        menuOptions.push('Divider');
+      }
+      if (isSomeone && canRemovePhotoFromPeople) {
+        menuOptions.push({
+          key: TextTranslation.REMOVE_FROM_GROUP.key,
+          value: TextTranslation.REMOVE_FROM_GROUP.value
+        });
+      }
+      if (!isSomeone && canAddPhotoToPeople) {
+        menuOptions.push({
+          key: TextTranslation.ADD_TO_GROUPS.key,
+          value: TextTranslation.ADD_TO_GROUPS.value
+        });
+      }
+    }
     return menuOptions;
   }
 
@@ -445,18 +483,17 @@ export const buildGalleryToolbarMenuOptions = (selectedImages, readOnly, metadat
     });
   }
 
-  if (isSomeone && !readOnly) {
+  if (isSomeone !== null && !readOnly) {
     menuOptions.push('Divider');
-
     const { canRemovePhotoFromPeople, canAddPhotoToPeople, canSetPeoplePhoto } = faceRecognitionPermission;
-    if (canRemovePhotoFromPeople) {
+    if (isSomeone && canRemovePhotoFromPeople) {
       menuOptions.push({
         key: TextTranslation.REMOVE_FROM_GROUP.key,
         value: TextTranslation.REMOVE_FROM_GROUP.value
       });
     }
 
-    if (canAddPhotoToPeople) {
+    if (!isSomeone && canAddPhotoToPeople) {
       menuOptions.push({
         key: TextTranslation.ADD_TO_GROUPS.key,
         value: TextTranslation.ADD_TO_GROUPS.value
@@ -577,10 +614,11 @@ export const buildCardToolbarMenuOptions = (records, readOnly, metadataStatus) =
   if (!records || records.length === 0) {
     return [];
   }
+  const isFolder = checkIsDir(records[0]);
   const menuOptions = [
     {
-      key: TextTranslation.OPEN_FILE_IN_NEW_TAB.key,
-      value: TextTranslation.OPEN_FILE_IN_NEW_TAB.value
+      key: isFolder ? TextTranslation.OPEN_FOLDER_IN_NEW_TAB.key : TextTranslation.OPEN_FILE_IN_NEW_TAB.key,
+      value: isFolder ? TextTranslation.OPEN_FOLDER_IN_NEW_TAB.value : TextTranslation.OPEN_FILE_IN_NEW_TAB.value,
     },
     {
       key: TextTranslation.OPEN_PARENT_FOLDER.key,
@@ -618,10 +656,11 @@ export const buildCardMenuOptions = (records, readOnly, metadataStatus) => {
   }
 
   const menuOptions = [];
+  const isFolder = checkIsDir(records[0]);
 
   menuOptions.push({
-    key: TextTranslation.OPEN_FILE_IN_NEW_TAB.key,
-    value: TextTranslation.OPEN_FILE_IN_NEW_TAB.value
+    key: isFolder ? TextTranslation.OPEN_FOLDER_IN_NEW_TAB.key : TextTranslation.OPEN_FILE_IN_NEW_TAB.key,
+    value: isFolder ? TextTranslation.OPEN_FOLDER_IN_NEW_TAB.value : TextTranslation.OPEN_FILE_IN_NEW_TAB.value,
   });
 
   menuOptions.push({
