@@ -110,7 +110,7 @@ const SimpleViewer = ({ sceneContent = null, isFetching, isInSdoc, isFullScreen,
 
   return (
     <>
-      <div className={classNames('excali-container', { 'in-sdoc': isInSdoc || isFullScreen })} style={{ height: '100vh', width: '100vw' }}>
+      <div className={classNames('excali-container', { 'in-sdoc': isInSdoc, 'full-screen': isFullScreen })} style={{ height: '100vh', width: '100vw' }}>
         <Excalidraw
           initialData={sceneContent}
           excalidrawAPI={(api) => setExcalidrawAPI(api)}
