@@ -23,6 +23,8 @@ import RepoShareAdminDialog from '../../components/dialog/repo-share-admin-dialo
 import OfficeSuiteDialog from '../../components/dialog/repo-office-suite-dialog';
 import { LIST_MODE } from '../../components/dir-view-mode/constants';
 import { userAPI } from '../../utils/user-api';
+import OpIcon from '../../components/op-icon';
+import { formatWithTimezone } from '../../utils/time';
 
 const propTypes = {
   currentViewMode: PropTypes.string,
@@ -61,13 +63,6 @@ class MylibRepoListItem extends React.Component {
     };
   }
 
-  onFocus = () => {
-    if (!this.props.isItemFreezed) {
-      this.setState({
-        isOpIconShow: true
-      });
-    }
-  };
 
   onMouseEnter = () => {
     if (!this.props.isItemFreezed) {
@@ -282,16 +277,19 @@ class MylibRepoListItem extends React.Component {
     let iconTitle = Utils.getLibIconTitle(repo);
     let repoURL = `${siteRoot}library/${repo.repo_id}/${Utils.encodePath(repo.repo_name)}/`;
     return currentViewMode == LIST_MODE ? (
-      <tr className={this.state.highlight ? 'tr-highlight' : ''} onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave} onFocus={this.onFocus} onContextMenu={this.handleContextMenu}>
+      <tr
+        className={this.state.highlight ? 'tr-highlight' : ''}
+        onMouseEnter={this.onMouseEnter}
+        onMouseLeave={this.onMouseLeave}
+        onFocus={this.onMouseEnter}
+        onContextMenu={this.handleContextMenu}
+      >
         <td className="text-center">
-          <i
-            role="button"
-            title={this.state.isStarred ? gettext('Unstar') : gettext('Star')}
-            aria-label={this.state.isStarred ? gettext('Unstar') : gettext('Star')}
-            onClick={this.onToggleStarRepo}
+          <OpIcon
             className={`${this.state.isStarred ? 'sf3-font-star' : 'sf3-font-star-empty'} sf3-font`}
-          >
-          </i>
+            title={this.state.isStarred ? gettext('Unstar') : gettext('Star')}
+            op={this.onToggleStarRepo}
+          />
         </td>
         <td><img src={iconUrl} title={iconTitle} alt={iconTitle} width="24" /></td>
         <td>
@@ -303,9 +301,7 @@ class MylibRepoListItem extends React.Component {
             />
           )}
           {!this.state.isRenaming && repo.repo_name && (
-            <Fragment>
-              <Link to={repoURL}>{repo.repo_name}</Link>
-            </Fragment>
+            <Link to={repoURL}>{repo.repo_name}</Link>
           )}
           {!this.state.isRenaming && !repo.repo_name &&
             (gettext('Broken (please contact your administrator to fix this library)'))
@@ -314,8 +310,16 @@ class MylibRepoListItem extends React.Component {
         <td>
           {(repo.repo_name && this.state.isOpIconShow) && (
             <div className="d-flex align-items-center">
-              <i className="op-icon sf3-font-share sf3-font" title={gettext('Share')} role="button" aria-label={gettext('Share')} onClick={this.onShareToggle}></i>
-              <i className="op-icon sf3-font-delete1 sf3-font" title={gettext('Delete')} role="button" aria-label={gettext('Delete')} onClick={this.onDeleteToggle}></i>
+              <OpIcon
+                className="op-icon sf3-font-share sf3-font"
+                title={gettext('Share')}
+                op={this.onShareToggle}
+              />
+              <OpIcon
+                className="op-icon sf3-font-delete1 sf3-font"
+                title={gettext('Delete')}
+                op={this.onDeleteToggle}
+              />
               <LibraryOpMenu
                 isPC={true}
                 repo={this.props.repo}
@@ -328,14 +332,14 @@ class MylibRepoListItem extends React.Component {
         </td>
         <td>{repo.size}</td>
         {(storages.length > 0 && !inAllLibs) && <td>{repo.storage_name}</td>}
-        <td title={dayjs(repo.last_modified).format('dddd, MMMM D, YYYY h:mm:ss A')}>{dayjs(repo.last_modified).fromNow()}</td>
+        <td title={formatWithTimezone(repo.last_modified)}>{dayjs(repo.last_modified).fromNow()}</td>
       </tr>
     ) : (
       <div
         className="library-grid-item px-3 d-flex justify-content-between align-items-center"
         onMouseEnter={this.onMouseEnter}
         onMouseLeave={this.onMouseLeave}
-        onFocus={this.onFocus}
+        onFocus={this.onMouseEnter}
         onContextMenu={this.handleContextMenu}
       >
         <div className="d-flex align-items-center text-truncate">
@@ -351,14 +355,11 @@ class MylibRepoListItem extends React.Component {
             <Fragment>
               <Link to={repoURL} className="library-name text-truncate" title={repo.repo_name}>{repo.repo_name}</Link>
               {isStarred &&
-                <i
-                  role="button"
-                  title={gettext('Unstar')}
-                  aria-label={gettext('Unstar')}
-                  className='op-icon library-grid-item-icon sf3-font-star sf3-font'
-                  onClick={this.onToggleStarRepo}
-                >
-                </i>
+              <OpIcon
+                className='op-icon library-grid-item-icon sf3-font-star sf3-font'
+                title={gettext('Unstar')}
+                op={this.onToggleStarRepo}
+              />
               }
             </Fragment>
           )}
@@ -368,8 +369,16 @@ class MylibRepoListItem extends React.Component {
         </div>
         {(repo.repo_name && this.state.isOpIconShow) && (
           <div className="flex-shrink-0 d-flex align-items-center">
-            <i className="op-icon sf3-font-share sf3-font" title={gettext('Share')} role="button" aria-label={gettext('Share')} onClick={this.onShareToggle}></i>
-            <i className="op-icon sf3-font-delete1 sf3-font" title={gettext('Delete')} role="button" aria-label={gettext('Delete')} onClick={this.onDeleteToggle}></i>
+            <OpIcon
+              className="op-icon sf3-font-share sf3-font"
+              title={gettext('Share')}
+              op={this.onShareToggle}
+            />
+            <OpIcon
+              className="op-icon sf3-font-delete1 sf3-font"
+              title={gettext('Delete')}
+              op={this.onDeleteToggle}
+            />
             <LibraryOpMenu
               isPC={true}
               repo={this.props.repo}
@@ -409,7 +418,7 @@ class MylibRepoListItem extends React.Component {
             <div>(gettext('Broken (please contact your administrator to fix this library)'))</div>
           }
           <span className="item-meta-info">{repo.size}</span>
-          <span className="item-meta-info" title={dayjs(repo.last_modified).format('dddd, MMMM D, YYYY h:mm:ss A')}>{dayjs(repo.last_modified).fromNow()}</span>
+          <span className="item-meta-info" title={formatWithTimezone(repo.last_modified)}>{dayjs(repo.last_modified).fromNow()}</span>
         </td>
         <td>
           {repo.repo_name && (
