@@ -42,6 +42,8 @@ class FileUploader extends React.Component {
       isUploadProgressDialogShow: false,
       currentResumableFile: null,
       uploadBitrate: 0,
+      filesUploadedNum: 0,
+      allFilesNum: 0,
     };
 
     this.uploadInput = React.createRef();
@@ -61,7 +63,7 @@ class FileUploader extends React.Component {
       target: '',
       query: this.setQuery || {},
       fileType: this.props.filetypes,
-      maxFiles: maxNumberOfFilesForFileupload || undefined,
+      maxFiles: undefined,
       maxFileSize: maxUploadFileSize * 1000 * 1000 || undefined,
       testMethod: this.props.testMethod || 'post',
       testChunks: this.props.testChunks || false,
@@ -124,6 +126,7 @@ class FileUploader extends React.Component {
   bindEventHandler = () => {
     this.resumable.on('chunkingComplete', this.onChunkingComplete.bind(this));
     this.resumable.on('fileAdded', this.onFileAdded.bind(this));
+    this.resumable.on('filesAddedComplete', this.filesAddedComplete.bind(this));
     this.resumable.on('fileProgress', this.onFileProgress.bind(this));
     this.resumable.on('fileSuccess', this.onFileUploadSuccess.bind(this));
     this.resumable.on('fileError', this.onFileError.bind(this));
@@ -186,27 +189,16 @@ class FileUploader extends React.Component {
           currentResumableFile: resumableFile,
         });
       } else {
-        this.setUploadFileList(this.resumable.files);
+        this.setUploadFileList();
         seafileAPI.sharedUploadLinkGetFileUploadUrl(this.props.token).then(res => {
           this.resumable.opts.target = res.data.upload_link + '?ret-json=1';
+          this.isUploadLinkLoaded = true;
           this.resumableUpload(resumableFile);
         }).catch(error => {
           let errMessage = Utils.getErrorMsg(error);
           toaster.danger(errMessage);
         });
       }
-    } else {
-      this.setUploadFileList(this.resumable.files);
-      if (!this.isUploadLinkLoaded) {
-        this.isUploadLinkLoaded = true;
-        seafileAPI.sharedUploadLinkGetFileUploadUrl(this.props.token).then(res => {
-          this.resumable.opts.target = res.data.upload_link + '?ret-json=1';
-          this.resumable.upload();
-        }).catch(error => {
-          let errMessage = Utils.getErrorMsg(error);
-          toaster.danger(errMessage);
-        });
-      }
     }
   };
 
@@ -232,13 +224,45 @@ class FileUploader extends React.Component {
         totalProgress: 100
       });
     }
+
+    const maxFiles = typeof maxNumberOfFilesForFileupload === 'number' ? maxNumberOfFilesForFileupload : null;
+    if (maxFiles && files && files.length > maxFiles) {
+      try {
+        (files || []).forEach(f => { if (f && typeof f.cancel === 'function') f.cancel(); });
+      } catch (e) {/* no-op */}
+      let message = gettext('Please upload no more than {maxFiles} files at a time.');
+      message = message.replace('{maxFiles}', maxFiles);
+      toaster.danger(message);
+      return;
+    }
+
+    if (files && files.length > 0) {
+      this.setUploadFileList();
+      if (!this.isUploadLinkLoaded) {
+        this.isUploadLinkLoaded = true;
+        seafileAPI.sharedUploadLinkGetFileUploadUrl(this.props.token)
+          .then(res => { this.resumable.opts.target = res.data.upload_link + '?ret-json=1'; this.resumable.upload(); })
+          .catch(error => { let errMessage = Utils.getErrorMsg(error); toaster.danger(errMessage); });
+      } else {
+        this.resumable.upload();
+      }
+    }
   };
 
   setUploadFileList = () => {
-    let uploadFileList = this.resumable.files;
+    let uploadFileList = Array.isArray(this.resumable.files) ? this.resumable.files.slice() : [];
+    uploadFileList = uploadFileList.map(item => {
+      if (!item.newFileName) {
+        const rel = item.relativePath || item.fileName || item.name;
+        item.newFileName = rel || '';
+      }
+      return item;
+    });
     this.setState({
       uploadFileList: uploadFileList,
       isUploadProgressDialogShow: true,
+      allFilesNum: uploadFileList.length,
+      filesUploadedNum: uploadFileList.reduce((acc, f) => acc + (f.isSaved ? 1 : 0), 0),
     });
     Utils.registerGlobalVariable('uploader', 'isUploadProgressDialogShow', true);
   };
@@ -335,7 +359,10 @@ class FileUploader extends React.Component {
         }
         return item;
       });
-      this.setState({ uploadFileList: uploadFileList });
+      this.setState(prev => ({
+        uploadFileList: uploadFileList,
+        filesUploadedNum: prev.filesUploadedNum + 1,
+      }));
 
       return;
     }
@@ -357,7 +384,10 @@ class FileUploader extends React.Component {
         }
         return item;
       });
-      this.setState({ uploadFileList: uploadFileList });
+      this.setState(prev => ({
+        uploadFileList: uploadFileList,
+        filesUploadedNum: prev.filesUploadedNum + 1,
+      }));
 
       return;
     }
@@ -379,7 +409,10 @@ class FileUploader extends React.Component {
       }
       return item;
     });
-    this.setState({ uploadFileList: uploadFileList });
+    this.setState(prev => ({
+      uploadFileList: uploadFileList,
+      filesUploadedNum: prev.filesUploadedNum + 1,
+    }));
   };
 
   onFileError = (resumableFile, message) => {
@@ -497,7 +530,7 @@ class FileUploader extends React.Component {
     this.resumable.files = [];
     // reset upload link loaded
     this.isUploadLinkLoaded = false;
-    this.setState({ isUploadProgressDialogShow: false, uploadFileList: [], forbidUploadFileList: [] });
+    this.setState({ isUploadProgressDialogShow: false, uploadFileList: [], forbidUploadFileList: [], filesUploadedNum: 0, allFilesNum: 0 });
     Utils.registerGlobalVariable('uploader', 'isUploadProgressDialogShow', false);
   };
 
@@ -518,7 +551,11 @@ class FileUploader extends React.Component {
       this.loaded = 0;
     }
 
-    this.setState({ uploadFileList: uploadFileList });
+    this.setState({
+      uploadFileList: uploadFileList,
+      allFilesNum: uploadFileList.length,
+      filesUploadedNum: uploadFileList.reduce((acc, f) => acc + (f.isSaved ? 1 : 0), 0),
+    });
   };
 
   onCancelAllUploading = () => {
@@ -534,7 +571,9 @@ class FileUploader extends React.Component {
 
     this.setState({
       totalProgress: 100,
-      uploadFileList: uploadFileList
+      uploadFileList: uploadFileList,
+      allFilesNum: uploadFileList.length,
+      filesUploadedNum: uploadFileList.reduce((acc, f) => acc + (f.isSaved ? 1 : 0), 0),
     });
     // reset upload link loaded
     this.isUploadLinkLoaded = false;
@@ -630,6 +669,8 @@ class FileUploader extends React.Component {
           forbidUploadFileList={this.state.forbidUploadFileList}
           totalProgress={this.state.totalProgress}
           uploadBitrate={this.state.uploadBitrate}
+          filesUploadedNum={this.state.filesUploadedNum}
+          allFilesNum={this.state.allFilesNum}
           onCloseUploadDialog={this.onCloseUploadDialog}
           onCancelAllUploading={this.onCancelAllUploading}
           onUploadCancel={this.onUploadCancel}
