@@ -1,4 +1,5 @@
 import React, { useCallback } from 'react';
+import { Utils } from '../../../utils/utils';
 
 import './plugin-item.css';
 
@@ -11,7 +12,13 @@ const CommentPlugin = ({ setIsShowRightPanel, unseenNotificationsCount }) => {
   }, []);
 
   return (
-    <span className="op-item wiki-plugin-operation-btn-container" onClick={handleOnClick}>
+    <span
+      className="op-item wiki-plugin-operation-btn-container"
+      onClick={handleOnClick}
+      role='button'
+      tabIndex={0}
+      onKeyDown={Utils.onKeyDown}
+    >
       <i className='sdocfont sdoc-comments'></i>
       {unseenNotificationsCount > 0 && (
         <span className="sdoc-unread-message-tip"></span>
