@@ -109,29 +109,39 @@ const TagFile = ({ repoID, file, tagsData, isRenaming, onRenameCancel, onRenameC
 
   return (
     <tr
+      tabIndex="0"
       className={classnames({
         'tr-highlight': highlight,
         'tr-active': isSelected
       })}
       onClick={handleClick}
+      onKeyDown={Utils.onKeyDown}
       onMouseEnter={onMouseEnter}
       onMouseLeave={onMouseLeave}
       onContextMenu={handleContextMenu}
     >
-      <td className="pl10 pr-2" role="button" onClick={handleSelected} aria-label={isSelected ? gettext('Unselect this item') : gettext('Select this item')}>
+      <td className="pl10 pr-2" onClick={handleSelected}>
         <input
           type="checkbox"
-          className="vam cursor-pointer"
-          style={{ position: 'relative', top: -1 }}
-          onClick={handleSelected}
-          onChange={() => {}}
+          className="cursor-pointer form-check-input"
           checked={isSelected}
           aria-label={isSelected ? gettext('Unselect this item') : gettext('Select this item')}
+          onChange={handleSelected}
+          onKeyDown={Utils.onKeyDown}
         />
       </td>
       <td className="pl-2 pr-2">
         <div className="dir-icon" onDragStart={(e) => e.preventDefault()}>
-          <img src={displayIcon} onError={onIconLoadError} className="thumbnail cursor-pointer" alt="" onClick={handleClickFileName} />
+          <img
+            src={displayIcon}
+            onError={onIconLoadError}
+            className="thumbnail cursor-pointer"
+            alt=""
+            onClick={handleClickFileName}
+            tabIndex="0"
+            role="button"
+            onKeyDown={Utils.onKeyDown}
+          />
         </div>
       </td>
       <td className="name">
