@@ -27,19 +27,23 @@
     "(current version)": "(aktu\u00e1lis verzi\u00f3)",
     "1 Year": "1 \u00e9v",
     "1 cell copied": "1 cell copied",
-    "1 filter": "1 filter",
+    "1 filter": "Egy sz\u0171r\u0151",
     "1 hidden property": "1 hidden property",
     "1 month ago": "1 h\u00f3napja",
     "1 preset hidden property": "1 preset hidden property",
     "1 record selected": "1 record selected",
     "1 row is copied.": "1 row is copied.",
-    "1 sort": "1 sort",
+    "1 sort": "Egy rendez\u00e9s",
     "1 week ago": "1 hete",
     "3 days ago": "3 napja",
     "30 Days": "30 nap",
     "7 Days": "7 nap",
     "A file is being uploaded. Are you sure you want to leave this page?": "A file is being uploaded. Are you sure you want to leave this page?",
+    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
+    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
     "A file with the same name already exists in this folder.": "A f\u00e1jl ezzel a n\u00e9vvel m\u00e1r l\u00e9tezik a k\u00f6nyvt\u00e1rban.",
+    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
+    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
     "API Token": "API Token",
     "API token is copied to the clipboard.": "API token is copied to the clipboard.",
     "About": "N\u00e9vjegy",
@@ -74,6 +78,7 @@
     "Add auto expiration": "Automatikus lej\u00e1rat be\u00e1ll\u00edt\u00e1sa",
     "Add cover": "Add cover",
     "Add custom permission": "Egyedi jogosults\u00e1g hozz\u00e1ad\u00e1sa",
+    "Add filter": "Sz\u0171r\u0151 hozz\u00e1ad\u00e1sa",
     "Add group": "Add group",
     "Add group member": "Add group member",
     "Add icon": "Add icon",
@@ -83,6 +88,7 @@
     "Add option": "Add option",
     "Add password protection": "Jelsz\u00f3 v\u00e9delem hozz\u00e1ad\u00e1sa",
     "Add permission": "Add permission",
+    "Add sort": "Rendez\u00e9s hozz\u00e1ad\u00e1sa",
     "Add user": "Felhaszn\u00e1l\u00f3 hozz\u00e1ad\u00e1sa",
     "Add view": "Add view",
     "Added": "Hozz\u00e1adva",
@@ -99,11 +105,12 @@
     "All Groups": "Minden csoport",
     "All Notifications": "\u00d6sszes \u00e9rtes\u00edt\u00e9s",
     "All Public Links": "\u00d6sszes nyilv\u00e1nos link",
+    "All comments": "\u00d6sszes megjegyz\u00e9s",
     "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Regisztr\u00e1ci\u00f3k enged\u00e9lyez\u00e9se. Vegye ki a pip\u00e1t, hogy megakad\u00e1lyozza \u00faj felhaszn\u00e1l\u00f3k regisztr\u00e1l\u00e1s\u00e1t.",
     "An integer that is greater than 0 or equal to -2.": "0-n\u00e1l nagyobb, vagy -2-vel egyenl\u0151 eg\u00e9sz sz\u00e1m.",
     "An integer that is greater than or equal to 0.": "0-n\u00e1l nagyobb vagy egyenl\u0151 eg\u00e9sz.",
     "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "A bels\u0151 link seg\u00edts\u00e9g\u00e9vel azon a felhaszn\u00e1l\u00f3k \u00e9rhetik el a f\u00e1jlt, vagy mapp\u00e1t, akik rendelkeznek olvas\u00e1si joggal az adott f\u00e1jlon, vagy mapp\u00e1n.",
-    "And": "And",
+    "And": " \u00c9s",
     "Anonymous User": "Anonymous felhaszn\u00e1l\u00f3",
     "Another property has this property type": "Another property has this property type",
     "Another user is editing this file!": "Another user is editing this file!",
@@ -111,6 +118,8 @@
     "Are you sure to change group {placeholder} to department ?": "Are you sure to change group {placeholder} to department ?",
     "Are you sure to delete": "Biztosan t\u00f6rli?",
     "Are you sure to delete ": "Are you sure to delete ",
+    "Are you sure to delete this comment?": "Biztosan t\u00f6r\u00f6lni szeretn\u00e9 ezt a kommentet?",
+    "Are you sure to delete this reply?": "Biztosan t\u00f6r\u00f6lni szeretn\u00e9 ezt a v\u00e1laszot?",
     "Are you sure to revoke access of user {placeholder} ?": "Are you sure to revoke access of user {placeholder} ?",
     "Are you sure you want to clear trash?": "Biztos, hogy \u00fcr\u00edti a kuk\u00e1t?",
     "Are you sure you want to delete": "Are you sure you want to delete",
@@ -164,6 +173,7 @@
     "Cannot move parent page to child page": "Cannot move parent page to child page",
     "Capture information": "Capture information",
     "Capture time": "Capture time",
+    "Card": "K\u00e1rtya",
     "Certificate": "Certificate",
     "Change": "V\u00e1ltoztat\u00e1s",
     "Change Password": "Jelsz\u00f3 v\u00e1ltoztat\u00e1s",
@@ -186,15 +196,17 @@
     "Close (Esc)": "Bez\u00e1r (Esc)",
     "Code": "K\u00f3d",
     "Collaborator": "Collaborator",
+    "Collaborators": "Kollabor\u00e1torok",
     "Collapse all": "Collapse all",
     "Color space": "Color space",
     "Comment": "Megjegyz\u00e9s",
+    "Comment details": "Koment r\u00e9szletei",
     "Comments": "Megjegyz\u00e9sek",
     "Community Edition": "K\u00f6z\u00f6ss\u00e9gi verzi\u00f3",
     "Compressed": "Compressed",
     "Configure Seafile": "Configure Seafile",
     "Configure your Identity Provider": "Configure your Identity Provider",
-    "Confirm": "Confirm",
+    "Confirm": "Meger\u0151s\u00edt\u00e9s",
     "Confirm Password": "Jelsz\u00f3 meger\u0151s\u00edt\u00e9se",
     "Confirm password": "Confirm password",
     "Connect": "Connect",
@@ -230,7 +242,7 @@
     "Create Library": "K\u00f6tet l\u00e9trehoz\u00e1sa",
     "Create Report": "Jelent\u00e9s k\u00e9sz\u00edt\u00e9se",
     "Create a DNS TXT record to confirm the ownership of your Email Domain.": "Create a DNS TXT record to confirm the ownership of your Email Domain.",
-    "Create a new tag": "Create a new tag",
+    "Create a new tag": "\u00daj c\u00edmke l\u00e9trehoz\u00e1sa",
     "Created": "L\u00e9trehozva",
     "Created At": "L\u00e9trehozva",
     "Created Files": "L\u00e9trehozott f\u00e1jlok",
@@ -240,7 +252,7 @@
     "Created group {group_name}": "Csoport l\u00e9trehozva: {group_name}",
     "Created library": "K\u00f6tet l\u00e9trehozva",
     "Created library {library_name} with {owner} as its owner": "{library_name} l\u00e9trehozva. Tulajdonos: {owner}",
-    "Created time": "Created time",
+    "Created time": "L\u00e9trehoz\u00e1s ideje",
     "Created {n} files": "Created {n} files",
     "Creator": "L\u00e9trehoz\u00f3",
     "Current Connected Devices": "Csatlakozott eszk\u00f6z\u00f6k",
@@ -330,7 +342,7 @@
     "Don't replace": "Ne cser\u00e9lje",
     "Don't send emails": "Don't send emails",
     "Done": "Done",
-    "Down": "Down",
+    "Down": "Cs\u00f6kken\u0151 sorrend",
     "Download": "Let\u00f6lt\u00e9s",
     "Download an example file": "Mintaf\u00e1jl let\u00f6lt\u00e9se",
     "Download and upload": "Let\u00f6lt\u00e9s \u00e9s felt\u00f6lt\u00e9s",
@@ -460,7 +472,7 @@
     "File type": "File type",
     "Files": "F\u00e1jlok",
     "Files and folders": "Files and folders",
-    "Filter": "Filter",
+    "Filter": "Sz\u0171r\u0151",
     "Filters": "Filters",
     "Find a tag": "Find a tag",
     "Find modifiers": "Find modifiers",
@@ -499,7 +511,7 @@
     "Handled": "Kezelve",
     "Help": "Seg\u00edts\u00e9g",
     "Hide": "Elrejt",
-    "Hide all": "Hide all",
+    "Hide all": "Mindet elrejt",
     "Hide properties": "Hide properties",
     "History": "Napl\u00f3",
     "History Setting": "Napl\u00f3be\u00e1ll\u00edt\u00e1sok",
@@ -530,7 +542,7 @@
     "Internal link has been copied to clipboard": "Bels\u0151 link a v\u00e1g\u00f3lapra m\u00e1solva",
     "Invalid destination path": "\u00c9rv\u00e9nytelen c\u00e9l \u00fatvonal",
     "Invalid filename.": "Invalid filename.",
-    "Invalid filter": "Invalid filter",
+    "Invalid filter": "\u00c9rv\u00e9nytelen sz\u0171r\u0151",
     "Invalid month, should be yyyymm.": "\u00c9rv\u00e9nytelen h\u00f3nap, helyes form\u00e1tum: \u00e9\u00e9\u00e9\u00e9-hh",
     "Invalid regular expression": "Invalid regular expression",
     "Invisible": "Invisible",
@@ -555,6 +567,7 @@
     "Last Access": "Utols\u00f3 el\u00e9r\u00e9s",
     "Last Login": "Utols\u00f3 bel\u00e9p\u00e9s",
     "Last Update": "Utols\u00f3 friss\u00edt\u00e9s ",
+    "Last modification": "Utols\u00f3 m\u00f3dos\u00edt\u00e1s",
     "Last modified by": "Utolj\u00e1ra m\u00f3dos\u00edt\u00f3",
     "Last modified time": "Last modified time",
     "Last modifier": "Last modifier",
@@ -568,7 +581,6 @@
     "Library": "K\u00f6tet",
     "Library Type": "K\u00f6tet t\u00edpusa",
     "Library does not exist": "A k\u00f6tet nem l\u00e9tezik",
-    "Library share permission not found.": "Library share permission not found.",
     "Limits": "Hat\u00e1rok",
     "Link": "Link",
     "Link has been copied to clipboard": "Link has been copied to clipboard",
@@ -589,6 +601,7 @@
     "Long text": "Long text",
     "Manage group members": "Csoporttagok kezel\u00e9se",
     "Manage members": "Manage members",
+    "Mark all as read": "Mindet olvasottnak jel\u00f6lje",
     "Mark all read": "Mindet olvasottnak jel\u00f6l",
     "Mark as resolved": "Megjel\u00f6l\u00e9s megoldottk\u00e9nt",
     "Max": "Max",
@@ -653,13 +666,12 @@
     "New PowerPoint File": "\u00daj PowerPoint f\u00e1jl",
     "New SeaDoc File": "New SeaDoc File",
     "New Sub-department": "\u00daj aloszt\u00e1ly",
-    "New Wiki name": "New Wiki name",
     "New Word File": "\u00daj Word f\u00e1jl",
     "New directories": "\u00daj k\u00f6nyvt\u00e1rak",
     "New file name": "\u00daj f\u00e1jl neve",
     "New files": "\u00daj f\u00e1jlok",
     "New folder name": "New folder name",
-    "New page": "New page",
+    "New page": "\u00daj oldal",
     "New password": "\u00daj jelsz\u00f3",
     "New password cannot be the same as old password": "New password cannot be the same as old password",
     "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.": "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.",
@@ -668,10 +680,11 @@
     "New view": "New view",
     "Next": "K\u00f6vetkez\u0151",
     "Next (Right arrow key)": "K\u00f6vetkez\u0151 (Jobbra ny\u00edl)",
+    "Next modification": "K\u00f6vetkez\u0151 m\u00f3dos\u00edt\u00e1s",
     "No Admin login logs": "No Admin login logs",
     "No Admin operation logs": "No Admin operation logs",
     "No Wikis": "No Wikis",
-    "No changes": "No changes",
+    "No changes": "Nincs v\u00e1ltoz\u00e1s",
     "No collaborators": "No collaborators",
     "No collaborators available": "No collaborators available",
     "No comment yet.": "Nincs m\u00e9g megjegyz\u00e9s",
@@ -681,7 +694,7 @@
     "No file": "No file",
     "No file access logs": "No file access logs",
     "No file update logs": "No file update logs",
-    "No filters": "No filters",
+    "No filters": "Nincs sz\u0171r\u0151",
     "No folders shared": "No folders shared",
     "No groupings applied to this view.": "No groupings applied to this view.",
     "No groups": "Nincs csoport",
@@ -707,9 +720,10 @@
     "No public libraries": "Nincs nyilv\u00e1nos k\u00f6nyvt\u00e1r",
     "No record": "No record",
     "No result": "Nincs tal\u00e1lat",
-    "No results": "No results",
+    "No results": "Nincs tal\u00e1lat",
     "No results matching": "No results matching",
     "No share links": "No share links",
+    "No sorts": "Nincs rendez\u00e9s",
     "No sync errors": "Nincs szinkroniz\u00e1l\u00e1si hiba",
     "No tags": "Nincsenek c\u00edmk\u00e9k",
     "No terms and conditions": "No terms and conditions",
@@ -764,7 +778,7 @@
     "Operations": "M\u0171veletek",
     "Optional": "Opcion\u00e1los",
     "Options imported": "Options imported",
-    "Or": "Or",
+    "Or": "Vagy",
     "Organization": "Szervezet",
     "Organization Admin": "Szervezeti adminisztr\u00e1tor",
     "Organizations": "Szervezetek",
@@ -774,6 +788,7 @@
     "Others": "Others",
     "Out of quota.": "Kv\u00f3ta t\u00fall\u00e9p\u00e9s.",
     "Outdated": "Outdated",
+    "Outline": "Kont\u00far",
     "Owned Libraries": "Birtokolt k\u00f6tetek",
     "Owner": "Tulajdonos",
     "Owner can use admin panel in an organization, must be a new account.": "A tulajdonos a szervezet be\u00e1ll\u00edt\u00e1sait kezelheti, \u00faj fi\u00f3knak kell lennie.",
@@ -832,7 +847,7 @@
     "Preview only": "Csak el\u0151n\u00e9zet",
     "Previous": "El\u0151z\u0151",
     "Previous (Left arrow key)": "El\u0151z\u0151 (Balra ny\u00edl)",
-    "Print": "Print",
+    "Print": "Nyomtat\u00e1s",
     "Professional Edition": "Professzion\u00e1lis verzi\u00f3",
     "Profile": "Profil",
     "Profile Setting": "Profilbe\u00e1ll\u00edt\u00e1sok",
@@ -884,6 +899,7 @@
     "Reset library password": "Reset library password",
     "ResetPwd": "\u00daj jelsz\u00f3",
     "Resetting user's password, please wait for a moment.": "Resetting user's password, please wait for a moment.",
+    "Resolved comments": "Megoldott megjegyz\u00e9sek",
     "Restore": "Vissza\u00e1ll\u00edt\u00e1s",
     "Restore Library": "K\u00f6tet vissza\u00e1ll\u00edt\u00e1sa",
     "Restored file": "Vissza\u00e1ll\u00edtott f\u00e1jl",
@@ -891,6 +907,7 @@
     "Restored library": "Vissza\u00e1ll\u00edtott k\u00f6tet",
     "Restored {name}": "Restored {name}",
     "Restored {name} and {n} other items": "Restored {name} and {n} other items",
+    "Resubmit": "\u00dajrak\u00fcld\u00e9s",
     "Result": "Tal\u00e1lat",
     "Revoke Access": "Revoke Access",
     "Revoke Admin": "Admin jog elv\u00e9tele",
@@ -910,15 +927,16 @@
     "Search Libraries": "Search Libraries",
     "Search Organizations": "Search Organizations",
     "Search Users": "Search Users",
-    "Search collaborator": "Search collaborator",
+    "Search collaborator": "K\u00f6zrem\u0171k\u00f6d\u0151 keres\u00e9se",
     "Search collaborators": "Search collaborators",
+    "Search department": "Szervezet keres\u00e9se",
     "Search files": "Search files",
     "Search files in this library": "F\u00e1jlok keres\u00e9se ebben a k\u00f6tetben",
     "Search groups": "Csoportok keres\u00e9se",
     "Search groups by name": "Search groups by name",
     "Search libraries by name or ID": "Search libraries by name or ID",
     "Search libraries by owner": "Search libraries by owner",
-    "Search option": "Search option",
+    "Search option": "Opci\u00f3 keres\u00e9se",
     "Search organizations": "Search organizations",
     "Search property": "Search property",
     "Search users": "Search users",
@@ -930,10 +948,10 @@
     "Select a user": "Select a user",
     "Select a user as admin": "Select a user as admin",
     "Select all": "Select all",
-    "Select an option": "Select an option",
+    "Select an option": "Egy opci\u00f3 kiv\u00e1laszt\u00e1sa",
     "Select collaborators": "Select collaborators",
     "Select libraries to share": "V\u00e1lasszon k\u00f6teteket a megoszt\u00e1shoz",
-    "Select option(s)": "Select option(s)",
+    "Select option(s)": "Opci\u00f3(k) kiv\u00e1laszt\u00e1sa",
     "Select up to 50 files": "Select up to 50 files",
     "Send": "K\u00fcld\u00e9s",
     "Send activation Email after user registration.": "Aktiv\u00e1l\u00f3 E-mail k\u00fcld\u00e9se regisztr\u00e1ci\u00f3 ut\u00e1n.",
@@ -987,14 +1005,14 @@
     "Shared with me": "Velem megosztva",
     "Show": "Mutat",
     "Show Codes": "K\u00f3dok mutat\u00e1sa",
-    "Show all": "Show all",
+    "Show all": "Mindet megjelen\u00edt",
     "Show changes": "Show changes",
     "Side Nav Menu": "Oldals\u00e1vi men\u00fc",
     "Single select": "Single select",
     "Site name used in email sending": "E-mailben megjelen\u0151 oldal neve",
     "Site title shown in a browser tab": "Oldal c\u00edme a b\u00f6ng\u00e9sz\u0151 f\u00fcl\u00f6n",
     "Size": "M\u00e9ret",
-    "Sort": "Sort",
+    "Sort": "Rendez\u00e9s",
     "Sort ascending": "Sort ascending",
     "Sort descending": "Sort descending",
     "Space Used": "Felhaszn\u00e1lt ter\u00fclet",
@@ -1009,7 +1027,7 @@
     "Storage": "T\u00e1rhely",
     "Storage Backend": "Storage Backend",
     "Storage Used": "Felhaszn\u00e1lt t\u00e1rhely",
-    "Style": "Style",
+    "Style": "St\u00edlus",
     "Submit": "Bek\u00fcld\u00e9s",
     "Success": "Sikeres",
     "Successfully added label(s) for library {placeholder}": "C\u00edmk\u00e9k hozz\u00e1adva a(z) {placeholder} k\u00f6tethez.",
@@ -1059,8 +1077,8 @@
     "Successfully unstarred {library_name_placeholder}.": "Successfully unstarred {library_name_placeholder}.",
     "Suggestion": "Javaslatok",
     "Switch sort mode": "Switch sort mode",
-    "Switch to plain text editor": "Switch to plain text editor",
-    "Switch to rich text editor": "Switch to rich text editor",
+    "Switch to plain text editor": "V\u00e1lt\u00e1s sz\u00f6veges szerkeszt\u0151re",
+    "Switch to rich text editor": "V\u00e1lt\u00e1s form\u00e1zott szerkeszt\u0151re",
     "Switch view mode": "Switch view mode",
     "Sync": "Szinkroniz\u00e1l\u00e1s",
     "Sync Download": "Szinkroniz\u00e1ci\u00f3 let\u00f6l\u00e9s",
@@ -1071,7 +1089,7 @@
     "System Info": "Rendszer inform\u00e1ci\u00f3",
     "System settings updated": "System settings updated",
     "Table": "T\u00e1bl\u00e1zat",
-    "Tag not found": "Tag not found",
+    "Tag not found": "Nincs el\u00e9rhet\u0151 opci\u00f3",
     "Tagged Files": "Tagged Files",
     "Tags": "Tagek",
     "Team name": "Team name",
@@ -1171,13 +1189,14 @@
     "Unlink": "Lev\u00e1laszt\u00e1s",
     "Unlink device": "Eszk\u00f6z sz\u00e9tkapcsol\u00e1sa",
     "Unlock": "Kinyit",
+    "Unresolved comments": "Nem megoldott megjegyz\u00e9sek",
     "Unselect": "Unselect",
     "Unshare": "Megoszt\u00e1s t\u00f6rl\u00e9se",
     "Unshare Library": "K\u00f6tet megoszt\u00e1s\u00e1nak visszavon\u00e1sa",
     "Unstar": "Nem kedvenc",
     "Untitled": "Untitled",
     "Unwatch File Changes": "Unwatch File Changes",
-    "Up": "Up",
+    "Up": "N\u00f6vekv\u0151 sorrend",
     "Update": "Friss\u00edt\u00e9s",
     "Update Terms and Conditions": "Felhaszn\u00e1l\u00e1si felt\u00e9telek friss\u00edt\u00e9se",
     "Update password": "Update password",
@@ -1273,12 +1292,12 @@
     "Zoom out": "Kicsiny\u00edt\u00e9s",
     "all": "\u00f6sszes",
     "all members": "minden tag",
-    "contains": "contains",
+    "contains": "Tartalmazza",
     "days": "nap",
     "deleted": "t\u00f6r\u00f6lve",
     "deleted option": "deleted option",
     "details": "details",
-    "does not contain": "does not contain",
+    "does not contain": "Nincs tartalmazza",
     "email is required": "email is required",
     "freezed": "freezed",
     "has all of...": "has all of...",
@@ -1286,17 +1305,17 @@
     "has none of...": "has none of...",
     "icon": "ikon",
     "in all libraries": "in all libraries",
-    "include the current user": "include the current user",
-    "is": "is",
+    "include the current user": "Be\u00e9rt\u00e9kezd\u00e9s",
+    "is": "E\u03af\u03bd\u03b1\u03b9",
     "is after...": "is after...",
     "is any of...": "is any of...",
     "is before...": "is before...",
-    "is current user's ID": "is current user's ID",
-    "is empty": "is empty",
+    "is current user's ID": "Jelenlegi felhaszn\u00e1l\u00f3i azonos\u00edt\u00f3",
+    "is empty": "\u00dcres",
     "is exactly...": "is exactly...",
     "is none of...": "is none of...",
-    "is not": "is not",
-    "is not empty": "is not empty",
+    "is not": "Nincs egyenl\u0151",
+    "is not empty": "Nem \u00fcres",
     "is on or after...": "is on or after...",
     "is on or before...": "is on or before...",
     "is within...": "is within...",
@@ -1312,7 +1331,7 @@
     "s": "s",
     "selected": "selected",
     "show more": "t\u00f6bb mutat\u00e1sa",
-    "sorts": "sorts",
+    "sorts": "Rendez\u00e9sek",
     "starred": "kedvenc",
     "state": "\u00e1llapot",
     "successfully added user %s.": "%s hozz\u00e1ad\u00e1sa sikeres.",
@@ -1324,6 +1343,7 @@
     "xxx records": "xxx records",
     "xxx records selected": "xxx records selected",
     "xxx rows are copied.": "xxx rows are copied.",
+    "you can also press \u2192": "a \u2192 gombot is haszn\u00e1lhatja ",
     "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
     "{file} and {n} other files": "{file} \u00e9s {n} egy\u00e9b f\u00e1jl",
     "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
