@@ -26,17 +26,21 @@
     "(current notification)": "(current notification)",
     "(current version)": "(trenutna razli\u010dica)",
     "1 cell copied": "1 cell copied",
-    "1 filter": "1 filter",
+    "1 filter": "1 filtriraj",
     "1 hidden property": "1 hidden property",
     "1 month ago": "pred 1 mesecem",
     "1 preset hidden property": "1 preset hidden property",
     "1 record selected": "1 record selected",
     "1 row is copied.": "1 row is copied.",
-    "1 sort": "1 sort",
+    "1 sort": "1 razvrstitev",
     "1 week ago": "pred 1 tednom",
     "3 days ago": "pred 3 dnevi",
     "A file is being uploaded. Are you sure you want to leave this page?": "Datoteka se nalagajo. Ali ste prepri\u010dani, da \u017eelite zapustiti to stran?",
+    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
+    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
     "A file with the same name already exists in this folder.": "Datoteka s tem imenom \u017ee obstaja v tej mapi.",
+    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
+    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
     "API Token": "API Token",
     "API token is copied to the clipboard.": "API token is copied to the clipboard.",
     "About Us": "O nas",
@@ -70,6 +74,7 @@
     "Add auto expiration": "Dodaj avtomatski \u010das veljavnosti",
     "Add cover": "Add cover",
     "Add custom permission": "Add custom permission",
+    "Add filter": "Dodaj filtriraj",
     "Add group": "Add group",
     "Add group member": "Add group member",
     "Add icon": "Add icon",
@@ -79,6 +84,7 @@
     "Add option": "Add option",
     "Add password protection": "Dodaj za\u0161\u010dito z geslom",
     "Add permission": "Add permission",
+    "Add sort": "Dodaj razvrstitev",
     "Add user": "Dodaj uporabnika",
     "Add view": "Add view",
     "Added": "Dodan",
@@ -94,11 +100,12 @@
     "All Groups": "Vse skupine",
     "All Notifications": "Vsa obvestila",
     "All Public Links": "Vse javne povezave",
+    "All comments": "Vsi komentarji",
     "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.",
     "An integer that is greater than 0 or equal to -2.": "An integer that is greater than 0 or equal to -2.",
     "An integer that is greater than or equal to 0.": "An integer that is greater than or equal to 0.",
-    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.",
-    "And": "And",
+    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "Opis interne povezave",
+    "And": "In",
     "Anonymous User": "Anonimni uporabnik",
     "Another property has this property type": "Another property has this property type",
     "Another user is editing this file!": "Another user is editing this file!",
@@ -106,6 +113,8 @@
     "Are you sure to change group {placeholder} to department ?": "Ali ste prepri\u010dani, da \u017eelite spremeniti skupino {placeholder} v oddelku?",
     "Are you sure to delete": "Ali ste prepri\u010dani, da \u017eelite izbrisati?",
     "Are you sure to delete ": "Ali ste prepri\u010dani, da \u017eelite izbrisati?",
+    "Are you sure to delete this comment?": "Ali ste prepri\u010dani, da \u017eelite izbrisati ta komentar?",
+    "Are you sure to delete this reply?": "Ali ste prepri\u010dani, da \u017eelite izbrisati ta odgovor?",
     "Are you sure to revoke access of user {placeholder} ?": "Ali ste prepri\u010dani, da \u017eelite preklicati dovoljenje uporabnika {placeholder}?",
     "Are you sure you want to clean invalid share links?": "Ali ste prepri\u010dani, da \u017eelite izbrisati neveljavne povezave za deljenje?",
     "Are you sure you want to clean invalid upload links?": "Ali ste prepri\u010dani, da \u017eelite izbrisati neveljavne povezave za prenos?",
@@ -166,6 +175,7 @@
     "Cannot move parent page to child page": "Cannot move parent page to child page",
     "Capture information": "Capture information",
     "Capture time": "Capture time",
+    "Card": "Karta",
     "Certificate": "Certificate",
     "Change": "Spremeni",
     "Change Password": "Spremeni geslo",
@@ -173,7 +183,7 @@
     "Change cover": "Change cover",
     "Change group to department": "Change group to department",
     "Change to department": "Change to department",
-    "Changes": "Changes",
+    "Changes": "Spremembe",
     "Checkbox": "Checkbox",
     "Choose date": "Choose date",
     "Clean": "Po\u010disti",
@@ -186,15 +196,19 @@
     "Clients": "Klient",
     "Close": "Zapri",
     "Close (Esc)": "Zapri (Esc)",
-    "Code": "Code",
+    "Code": "Vmesni kodo",
     "Collaborator": "Collaborator",
+    "Collaborators": "Pridobniki",
     "Collapse all": "Collapse all",
     "Color space": "Color space",
+    "Comment": "Komentar",
+    "Comment details": "Detalji komentarja",
+    "Comments": "Komentarji",
     "Community Edition": "Community Edition",
     "Compressed": "Compressed",
     "Configure Seafile": "Configure Seafile",
     "Configure your Identity Provider": "Configure your Identity Provider",
-    "Confirm": "Confirm",
+    "Confirm": "Potrdi",
     "Confirm Password": "Potrdite geslo",
     "Confirm password": "Confirm password",
     "Connect": "Connect",
@@ -210,7 +224,7 @@
     "Convert to sdoc": "Convert to sdoc",
     "Convert with ONLYOFFICE": "Convert with ONLYOFFICE",
     "Converting, please wait...": "Converting, please wait...",
-    "Copied": "Copied",
+    "Copied": "Kopirano",
     "Copied link to clipboard": "Copied link to clipboard",
     "Copy": "Kopiraj",
     "Copy failed": "Copy failed",
@@ -230,7 +244,7 @@
     "Create Library": "Create Library",
     "Create Report": "Create Report",
     "Create a DNS TXT record to confirm the ownership of your Email Domain.": "Create a DNS TXT record to confirm the ownership of your Email Domain.",
-    "Create a new tag": "Create a new tag",
+    "Create a new tag": "Dodaj mo\u017enost",
     "Created": "Created",
     "Created At": "Ustvarjeno ob",
     "Created Files": "Created Files",
@@ -240,7 +254,7 @@
     "Created group {group_name}": "Created group {group_name}",
     "Created library": "Ustvarjena knji\u017enica",
     "Created library {library_name} with {owner} as its owner": "Created library {library_name} with {owner} as its owner",
-    "Created time": "Created time",
+    "Created time": "Ustvarjeno",
     "Created {n} files": "Created {n} files",
     "Creator": "Ustvaril",
     "Current Connected Devices": "Current Connected Devices",
@@ -328,7 +342,7 @@
     "Don't replace": "Don't replace",
     "Don't send emails": "Don't send emails",
     "Done": "Done",
-    "Down": "Down",
+    "Down": "Navzdol",
     "Download": "Prenos",
     "Download and upload": "Download and upload",
     "Duplicate": "Duplicate",
@@ -462,7 +476,7 @@
     "File type": "File type",
     "Files": "Datoteke",
     "Files and folders": "Files and folders",
-    "Filter": "Filter",
+    "Filter": "Filtriraj",
     "Filters": "Filters",
     "Find a tag": "Find a tag",
     "Find modifiers": "Find modifiers",
@@ -477,6 +491,7 @@
     "Freeze Document": "Freeze Document",
     "Freeze user account when failed login attempts exceed limit.": "Freeze user account when failed login attempts exceed limit.",
     "Frozen by {name}": "Frozen by {name}",
+    "Full screen": "Prikaz v celotni zaslon",
     "Gallery": "Gallery",
     "General information": "General information",
     "Generate": "Ustvari",
@@ -499,7 +514,7 @@
     "Handled": "Handled",
     "Help": "Pomo\u010d",
     "Hide": "Skrij",
-    "Hide all": "Hide all",
+    "Hide all": "Sakri vse",
     "Hide properties": "Hide properties",
     "History": "Zgodovina",
     "History Versions": "History Versions",
@@ -524,10 +539,10 @@
     "Institution Admin": "Upravnik institucije",
     "Internal Link": "Internal Link",
     "Internal Server Error": "Notranja napaka stre\u017enika",
-    "Internal link has been copied to clipboard": "Internal link has been copied to clipboard",
+    "Internal link has been copied to clipboard": "Kopiraj interni povezavo",
     "Invalid destination path": "Neveljavna kon\u010dna pot",
     "Invalid filename.": "Invalid filename.",
-    "Invalid filter": "Invalid filter",
+    "Invalid filter": "Napa\u010den filtriraj",
     "Invalid month, should be yyyymm.": "Invalid month, should be yyyymm.",
     "Invalid regular expression": "Invalid regular expression",
     "Invisible": "Invisible",
@@ -552,6 +567,7 @@
     "Last Access": "Zadnji\u010d dostopano",
     "Last Login": "Zadnja prijava",
     "Last Update": "Posodobljeno",
+    "Last modification": "Zadnja sprememba",
     "Last modified by": "Last modified by",
     "Last modified time": "Last modified time",
     "Last modifier": "Last modifier",
@@ -565,7 +581,6 @@
     "Library": "Knji\u017enica",
     "Library Type": "Library Type",
     "Library does not exist": "Knji\u017enica ne obstaja",
-    "Library share permission not found.": "Library share permission not found.",
     "Limits": "Omejitve",
     "Link": "Povezava",
     "Link has been copied to clipboard": "Link has been copied to clipboard",
@@ -576,7 +591,7 @@
     "Load all": "Load all",
     "Loading": "Loading",
     "Loading...": "Nalagam...",
-    "Location": "Location",
+    "Location": "Lokacija",
     "Lock": "Zakleni",
     "Log out": "Odjava",
     "Login": "Login",
@@ -588,6 +603,7 @@
     "Manage members": "Manage members",
     "Mark all as read": "Ozna\u010di vse kot prebrane",
     "Mark all read": "Ozna\u010di kot prebrano",
+    "Mark as resolved": "Ozna\u010di kot re\u0161eno",
     "Max": "Max",
     "Max number of members": "Max number of members",
     "Member": "\u010clan",
@@ -636,7 +652,7 @@
     "Name updated": "Name updated",
     "Name(optional)": "Ime (opcija)",
     "Network error": "Network error",
-    "New": "New",
+    "New": "Nova",
     "New Department": "New Department",
     "New Department Library": "New Department Library",
     "New Excel File": "New Excel File",
@@ -650,7 +666,6 @@
     "New PowerPoint File": "New PowerPoint File",
     "New SeaDoc File": "New SeaDoc File",
     "New Sub-department": "New Sub-department",
-    "New Wiki name": "New Wiki name",
     "New Word File": "New Word File",
     "New directories": "Nove mape",
     "New file name": "New file name",
@@ -665,19 +680,21 @@
     "New view": "New view",
     "Next": "Naslednja",
     "Next (Right arrow key)": "Naprej (Desna pu\u0161\u010dica)",
+    "Next modification": "Naslednja sprememba",
     "No Admin login logs": "No Admin login logs",
     "No Admin operation logs": "No Admin operation logs",
     "No Wikis": "No Wikis",
-    "No changes": "No changes",
+    "No changes": "Ni sprememb",
     "No collaborators": "No collaborators",
     "No collaborators available": "No collaborators available",
+    "No comment yet.": "Trenutno \u0161e ni noben komentar",
     "No connected devices": "No connected devices",
     "No deleted libraries": "No deleted libraries",
     "No favorites": "No favorites",
     "No file": "No file",
     "No file access logs": "No file access logs",
     "No file update logs": "No file update logs",
-    "No filters": "No filters",
+    "No filters": "Ni filtrov",
     "No folders shared": "No folders shared",
     "No groupings applied to this view.": "No groupings applied to this view.",
     "No groups": "No groups",
@@ -702,11 +719,12 @@
     "No properties available to be hidden": "No properties available to be hidden",
     "No record": "No record",
     "No result": "Brez zadetka",
-    "No results": "No results",
+    "No results": "Ni rezultata",
     "No results matching": "No results matching",
     "No share links": "No share links",
+    "No sorts": "Ni razvrstitev",
     "No sync errors": "No sync errors",
-    "No tags": "No tags",
+    "No tags": "Noben oznaka",
     "No terms and conditions": "No terms and conditions",
     "No upload links": "No upload links",
     "No version history": "No version history",
@@ -752,14 +770,14 @@
     "Open folder": "Open folder",
     "Open folder in new tab": "Open folder in new tab",
     "Open in new tab": "Open in new tab",
-    "Open parent folder": "Open parent folder",
+    "Open parent folder": "Odpri nadrejeno mapo",
     "Open via Client": "Odpri s klientom",
     "Operation": "Mo\u017enosti",
     "Operation succeeded.": "Operacija uspe\u0161no izvedena.",
     "Operations": "Operacije",
     "Optional": "Izbirno",
     "Options imported": "Options imported",
-    "Or": "Or",
+    "Or": "Ali",
     "Organization": "Organizacija",
     "Organization Admin": "Skrbnik organizacije",
     "Organizations": "Organizacija",
@@ -769,6 +787,7 @@
     "Others": "Others",
     "Out of quota.": "Out of quota.",
     "Outdated": "Outdated",
+    "Outline": "Navodilo",
     "Owned Libraries": "Owned Libraries",
     "Owner": "Lastnik",
     "Owner can use admin panel in an organization, must be a new account.": "Lastnik lahko uporabi nadzorno plo\u0161\u010do v organizaciji, mora biti nov ra\u010dun.",
@@ -806,7 +825,7 @@
     "Please choose an image file.": "Please choose an image file.",
     "Please enter 1 or more character": "Prosimo, vpi\u0161i 1 ali ve\u010d znakov",
     "Please enter a new password": "Please enter a new password",
-    "Please enter a non-negative integer": "Please enter a non-negative integer",
+    "Please enter a non-negative integer": "Prosimo, vnesite nenegativno celo \u0161tevilo",
     "Please enter a password.": "Please enter a password.",
     "Please enter a positive integer": "Please enter a positive integer",
     "Please enter an integer bigger than 1 as number of links.": "Please enter an integer bigger than 1 as number of links.",
@@ -822,19 +841,20 @@
     "Please select an expiration time": "Please select an expiration time",
     "Please upload no more than {maxFiles} files at a time.": "Please upload no more than {maxFiles} files at a time.",
     "Preset hide properties": "Preset hide properties",
-    "Preview and download": "Preview and download",
+    "Preview and download": "Pregledaj in preveri",
     "Preview online": "Preview online",
-    "Preview only": "Preview only",
+    "Preview only": "Pregledaj le",
     "Previous": "Prej\u0161nja",
     "Previous (Left arrow key)": "Prej\u0161nji (Leva pu\u0161\u010dica)",
-    "Print": "Print",
+    "Print": "Natisni",
     "Professional Edition": "Professional Edition",
     "Profile": "Profil",
     "Profile Setting": "Nastavitve profila",
     "Properties": "Properties",
     "Property name": "Property name",
-    "Publish": "Publish",
+    "Publish": "Objavi",
     "Publish Wiki": "Publish Wiki",
+    "Published": "Objavljeno",
     "Quota": "Quota",
     "Quota is invalid.": "Quota is invalid.",
     "Rate": "Rate",
@@ -848,7 +868,7 @@
     "Really want to delete your account?": "Ali res \u017eelite odstraniti svoj ra\u010dun?",
     "Really want to leave this group?": "Really want to leave this group?",
     "Recognizing portraits. Please refresh the page later.": "Recognizing portraits. Please refresh the page later.",
-    "Refresh": "Refresh",
+    "Refresh": "Ponovno nalo\u017ei",
     "Remove": "Odstrani",
     "Rename": "Preimenuj",
     "Rename Department": "Rename Department",
@@ -865,7 +885,7 @@
     "Renamed library": "Renamed library",
     "Renamed or Moved files": "Preimenovane ali premaknjene datoteke",
     "Renaming {name} failed": "Renaming {name} failed",
-    "Replace": "Replace",
+    "Replace": "Zamenjaj",
     "Replace file {filename}?": "Replace file {filename}?",
     "Replacing it will overwrite its content.": "Replacing it will overwrite its content.",
     "Report Abuse": "Report Abuse",
@@ -878,6 +898,7 @@
     "Reset library password": "Reset library password",
     "ResetPwd": "Spremen.Geslo",
     "Resetting user's password, please wait for a moment.": "Resetting user's password, please wait for a moment.",
+    "Resolved comments": "Risoljeni komentarji",
     "Restore": "Obnovi",
     "Restore Library": "Obnovi knji\u017enico",
     "Restored file": "Restored file",
@@ -885,33 +906,35 @@
     "Restored library": "Restored library",
     "Restored {name}": "Restored {name}",
     "Restored {name} and {n} other items": "Restored {name} and {n} other items",
+    "Resubmit": "Ponovi potrditev",
     "Result": "Rezultat",
     "Revoke Access": "Revoke Access",
     "Revoke Admin": "Odstrani iz admin",
     "Role": "Vloga",
     "SAML config": "SAML config",
     "SAML config updated": "SAML config updated",
-    "Save": "Save",
+    "Save": "Shrani",
     "Save Selected Items": "Save Selected Items",
     "Save to:": "Save to:",
     "Saving...": "Shranjujem\u2026.",
     "Scan the QR code to view the shared content directly": "Skenirajte QR kodo za neposredno ogled vsebine v skupni rabi",
     "SeaTable integration": "SeaTable integration",
     "Seafile": "Seafile",
-    "Search": "Search",
+    "Search": "Iskanje",
     "Search Groups": "Search Groups",
     "Search Libraries": "Search Libraries",
     "Search Organizations": "Search Organizations",
     "Search Users": "Search Users",
-    "Search collaborator": "Search collaborator",
+    "Search collaborator": "Iskanje pridobnika",
     "Search collaborators": "Search collaborators",
+    "Search department": "Iskanje oddelkov",
     "Search files": "Search files",
     "Search files in this library": "Iskanje datotek v tej knji\u017enici",
     "Search groups": "Search groups",
     "Search groups by name": "Search groups by name",
     "Search libraries by name or ID": "Search libraries by name or ID",
     "Search libraries by owner": "Search libraries by owner",
-    "Search option": "Search option",
+    "Search option": "Iskanje mo\u017enosti",
     "Search organizations": "Search organizations",
     "Search property": "Search property",
     "Search users": "Search users",
@@ -922,10 +945,10 @@
     "Select a user": "Select a user",
     "Select a user as admin": "Select a user as admin",
     "Select all": "Select all",
-    "Select an option": "Select an option",
+    "Select an option": "Izberi mo\u017enost",
     "Select collaborators": "Select collaborators",
     "Select libraries to share": "Izberi knji\u017enice za skupno rabo",
-    "Select option(s)": "Select option(s)",
+    "Select option(s)": "Izberi mo\u017enost(je)",
     "Select up to 50 files": "Select up to 50 files",
     "Send": "Po\u0161lji",
     "Send activation Email after user registration.": "Send activation Email after user registration.",
@@ -944,6 +967,7 @@
     "Set WebDAV Password": "Set WebDAV Password",
     "Set max number of members": "Set max number of members",
     "Set password": "Set password",
+    "Set permission": "Ustavi dovoljenja",
     "Set permission of {placeholder}": "Set permission of {placeholder}",
     "Set to current": "Nastavi na trenutno",
     "Set user contact email": "Set user contact email",
@@ -974,14 +998,14 @@
     "Shared with all": "Deljeno z vsemi",
     "Shared with me": "Deljeno z mano",
     "Show": "Prika\u017ei",
-    "Show all": "Show all",
+    "Show all": "Prika\u017ei vse",
     "Show changes": "Show changes",
     "Side Nav Menu": "Side Nav Menu",
     "Single select": "Single select",
     "Site name used in email sending": "Site name used in email sending",
     "Site title shown in a browser tab": "Site title shown in a browser tab",
     "Size": "Velikost",
-    "Sort": "Sort",
+    "Sort": "Razvrsti",
     "Sort ascending": "Sort ascending",
     "Sort descending": "Sort descending",
     "Space Used": "Poraba prostora",
@@ -995,7 +1019,7 @@
     "Storage": "Storage",
     "Storage Backend": "Storage Backend",
     "Storage Used": "Storage Used",
-    "Style": "Style",
+    "Style": "Stil",
     "Submit": "Potrdi",
     "Success": "Uspeh",
     "Successfully added label(s) for library {placeholder}": "Successfully added label(s) for library {placeholder}",
@@ -1041,10 +1065,10 @@
     "Successfully unlinked the device.": "Successfully unlinked the device.",
     "Successfully unshared {name}": "Successfully unshared {name}",
     "Successfully unstarred {library_name_placeholder}.": "Successfully unstarred {library_name_placeholder}.",
-    "Suggestion": "Suggestion",
+    "Suggestion": "Pristop",
     "Switch sort mode": "Switch sort mode",
-    "Switch to plain text editor": "Switch to plain text editor",
-    "Switch to rich text editor": "Switch to rich text editor",
+    "Switch to plain text editor": "Preklopi v besedilni urejevalnik",
+    "Switch to rich text editor": "Preklopi v virete urejevalnik",
     "Switch view mode": "Switch view mode",
     "Sync": "Sync",
     "Sync Download": "Sync Download",
@@ -1054,9 +1078,9 @@
     "System Info": "Informacije o sistemu",
     "System settings updated": "System settings updated",
     "Table": "Tabela",
-    "Tag not found": "Tag not found",
+    "Tag not found": "Oznaka ni bila najdena.",
     "Tagged Files": "Tagged Files",
-    "Tags": "Tags",
+    "Tags": "Oznake",
     "Team name": "Team name",
     "Template": "Template",
     "Terms": "Terms",
@@ -1090,7 +1114,7 @@
     "There is another option with this name": "There is another option with this name",
     "There is another property with this name": "There is another property with this name",
     "There is no information to display.": "There is no information to display.",
-    "This file has been updated.": "This file has been updated.",
+    "This file has been updated.": "Datoteka je posodobljena",
     "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).": "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).",
     "This folder has no content at this time.": "This folder has no content at this time.",
     "This is a special group representing a department.": "This is a special group representing a department.",
@@ -1152,13 +1176,14 @@
     "Unlink": "Odstrani",
     "Unlink device": "Unlink device",
     "Unlock": "Odkleni",
+    "Unresolved comments": "Nerisoljeni komentarji",
     "Unselect": "Unselect",
     "Unshare": "Odstrani deljenje",
     "Unshare Library": "Odstrani knji\u017enico iz deljenja",
     "Unstar": "Odstrani pomembno",
     "Untitled": "Untitled",
     "Unwatch File Changes": "Unwatch File Changes",
-    "Up": "Up",
+    "Up": "Navzgor",
     "Update": "Posodobi",
     "Update Terms and Conditions": "Update Terms and Conditions",
     "Update password": "Update password",
@@ -1251,12 +1276,12 @@
     "ZIP": "ZIP",
     "all": "skupaj",
     "all members": "vsi \u010dlani",
-    "contains": "contains",
+    "contains": " vsebuje",
     "days": "dni",
     "deleted": "deleted",
     "deleted option": "deleted option",
     "details": "details",
-    "does not contain": "does not contain",
+    "does not contain": " ne vsebuje",
     "email is required": "E-po\u0161ta je zahtevana",
     "freezed": "freezed",
     "has all of...": "has all of...",
@@ -1264,17 +1289,17 @@
     "has none of...": "has none of...",
     "icon": "ikona",
     "in all libraries": "in all libraries",
-    "include the current user": "include the current user",
-    "is": "is",
+    "include the current user": "vklju\u010dite me",
+    "is": " je",
     "is after...": "is after...",
     "is any of...": "is any of...",
     "is before...": "is before...",
-    "is current user's ID": "is current user's ID",
-    "is empty": "is empty",
+    "is current user's ID": " je ID trenutnega uporabnika",
+    "is empty": " je prazno",
     "is exactly...": "is exactly...",
     "is none of...": "is none of...",
-    "is not": "is not",
-    "is not empty": "is not empty",
+    "is not": " ni",
+    "is not empty": " ni prazno",
     "is on or after...": "is on or after...",
     "is on or before...": "is on or before...",
     "is within...": "is within...",
@@ -1290,7 +1315,7 @@
     "s": "s",
     "selected": "selected",
     "show more": "show more",
-    "sorts": "sorts",
+    "sorts": "Razvrstitev",
     "starred": "pomembno",
     "successfully added user %s.": "successfully added user %s.",
     "successfully sent email to %s.": "successfully sent email to %s.",
@@ -1301,6 +1326,7 @@
     "xxx records": "xxx records",
     "xxx records selected": "xxx records selected",
     "xxx rows are copied.": "xxx rows are copied.",
+    "you can also press \u2192": "you can also press \u2192",
     "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
     "{file} and {n} other files": "{file} and {n} other files",
     "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
