@@ -27,19 +27,23 @@
     "(current version)": "(pa\u0161reiz\u0113j\u0101 versija)",
     "1 Year": "1 gads",
     "1 cell copied": "1 cell copied",
-    "1 filter": "1 filter",
+    "1 filter": "1 filtrs",
     "1 hidden property": "1 hidden property",
     "1 month ago": "Pirms 1 m\u0113ne\u0161a",
     "1 preset hidden property": "1 preset hidden property",
     "1 record selected": "1 record selected",
     "1 row is copied.": "1 row is copied.",
-    "1 sort": "1 sort",
+    "1 sort": "1 r\u0101d\u012b\u0161ana",
     "1 week ago": "Pirms 1 ned\u0113\u013cas",
     "3 days ago": "Pirms 3 dien\u0101m",
     "30 Days": "30 dienas",
     "7 Days": "7 dienas",
     "A file is being uploaded. Are you sure you want to leave this page?": "A file is being uploaded. Are you sure you want to leave this page?",
+    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
+    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
     "A file with the same name already exists in this folder.": "Datne ar t\u0101du pa\u0161u nosaukumu jau eksist\u0113 \u0161aj\u0101 map\u0113.",
+    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
+    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
     "API Token": "API Token",
     "API token is copied to the clipboard.": "API token is copied to the clipboard.",
     "About": "Par",
@@ -74,6 +78,7 @@
     "Add auto expiration": "Pievienot autom\u0101tisko izbeig\u0161anos",
     "Add cover": "Add cover",
     "Add custom permission": "Add custom permission",
+    "Add filter": "Pievienot filtru",
     "Add group": "Add group",
     "Add group member": "Add group member",
     "Add icon": "Add icon",
@@ -83,6 +88,7 @@
     "Add option": "Add option",
     "Add password protection": "Pievienot paroles aizsardz\u012bbu",
     "Add permission": "Add permission",
+    "Add sort": "Pievienot r\u0101d\u012b\u0161anas opciju",
     "Add user": "Pievienot lietot\u0101ju",
     "Add view": "Add view",
     "Added": "Pievienots",
@@ -98,17 +104,20 @@
     "All Groups": "Visas grupas",
     "All Notifications": "Visi pazi\u0146ojumi",
     "All Public Links": "Visas publisk\u0101s saites",
+    "All comments": "Visi koment\u0101ri",
     "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.",
     "An integer that is greater than 0 or equal to -2.": "An integer that is greater than 0 or equal to -2.",
     "An integer that is greater than or equal to 0.": "An integer that is greater than or equal to 0.",
-    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.",
-    "And": "And",
+    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "Iek\u0161\u0113jais linka apraksts",
+    "And": "Un",
     "Anonymous User": "Anon\u012bms lietot\u0101js",
     "Another property has this property type": "Another property has this property type",
     "Another user is editing this file!": "Another user is editing this file!",
     "Anyone with the link": "Anyone with the link",
     "Are you sure to change group {placeholder} to department ?": "Are you sure to change group {placeholder} to department ?",
     "Are you sure to delete ": "Are you sure to delete ",
+    "Are you sure to delete this comment?": "Vai tie\u0161\u0101m v\u0113laties dz\u0113st \u0161o koment\u0101ru?",
+    "Are you sure to delete this reply?": "Vai tie\u0161\u0101m v\u0113laties dz\u0113st \u0161o atbildi?",
     "Are you sure to revoke access of user {placeholder} ?": "Are you sure to revoke access of user {placeholder} ?",
     "Are you sure you want to clear trash?": "Vai tie\u0161\u0101m v\u0113laties t\u012br\u012bt atkritni?",
     "Are you sure you want to delete": "Are you sure you want to delete",
@@ -162,6 +171,7 @@
     "Cannot move parent page to child page": "Cannot move parent page to child page",
     "Capture information": "Capture information",
     "Capture time": "Capture time",
+    "Card": "Kart\u012bte",
     "Certificate": "Certificate",
     "Change": "Main\u012bt",
     "Change Password": "Main\u012bt paroli",
@@ -169,7 +179,7 @@
     "Change cover": "Change cover",
     "Change group to department": "Change group to department",
     "Change to department": "Change to department",
-    "Changes": "Changes",
+    "Changes": "Izmai\u0146as",
     "Checkbox": "Checkbox",
     "Choose date": "Choose date",
     "Clean": "T\u012br\u012bt",
@@ -182,17 +192,19 @@
     "Clients": "Klienti",
     "Close": "Aizv\u0113rt",
     "Close (Esc)": "Aizv\u0113rt (Esc)",
-    "Code": "Code",
+    "Code": "V\u0113rt\u012bbu kods",
     "Collaborator": "Collaborator",
+    "Collaborators": "Paticipanti",
     "Collapse all": "Collapse all",
     "Color space": "Color space",
     "Comment": "Koment\u0101rs",
+    "Comment details": "Koment\u0101ra deta\u013ci",
     "Comments": "Koment\u0101ri",
     "Community Edition": "Community Edition",
     "Compressed": "Compressed",
     "Configure Seafile": "Configure Seafile",
     "Configure your Identity Provider": "Configure your Identity Provider",
-    "Confirm": "Confirm",
+    "Confirm": "P\u0101rbaud\u012bt",
     "Confirm Password": "Apstiprin\u0101t paroli",
     "Confirm password": "Confirm password",
     "Connect": "Connect",
@@ -208,7 +220,7 @@
     "Convert to sdoc": "Convert to sdoc",
     "Convert with ONLYOFFICE": "Convert with ONLYOFFICE",
     "Converting, please wait...": "Converting, please wait...",
-    "Copied": "Copied",
+    "Copied": "Kop\u0113ts",
     "Copied link to clipboard": "Copied link to clipboard",
     "Copy": "Kop\u0113t",
     "Copy failed": "Copy failed",
@@ -228,7 +240,7 @@
     "Create Library": "Create Library",
     "Create Report": "Create Report",
     "Create a DNS TXT record to confirm the ownership of your Email Domain.": "Create a DNS TXT record to confirm the ownership of your Email Domain.",
-    "Create a new tag": "Create a new tag",
+    "Create a new tag": "Izveidot jaunu tagu",
     "Created": "Izveidoja",
     "Created At": "Izveidoja",
     "Created Files": "Created Files",
@@ -238,7 +250,7 @@
     "Created group {group_name}": "Created group {group_name}",
     "Created library": "Kr\u0101tuve izveidota",
     "Created library {library_name} with {owner} as its owner": "Created library {library_name} with {owner} as its owner",
-    "Created time": "Created time",
+    "Created time": "Izveido\u0161anas laiks",
     "Created {n} files": "Created {n} files",
     "Creator": "Autors",
     "Current Connected Devices": "Tagad savienotas ier\u012bces",
@@ -327,7 +339,7 @@
     "Don't replace": "Neaizst\u0101t",
     "Don't send emails": "Don't send emails",
     "Done": "Done",
-    "Down": "Down",
+    "Down": "Apak\u0161\u0101",
     "Download": "Lejupl\u0101d\u0113t",
     "Download and upload": "Download and upload",
     "Duplicate": "Duplicate",
@@ -456,7 +468,7 @@
     "File type": "File type",
     "Files": "Datnes",
     "Files and folders": "Files and folders",
-    "Filter": "Filter",
+    "Filter": "Filtr\u0113t",
     "Filters": "Filters",
     "Find a tag": "Find a tag",
     "Find modifiers": "Find modifiers",
@@ -471,6 +483,7 @@
     "Freeze Document": "Freeze Document",
     "Freeze user account when failed login attempts exceed limit.": "Freeze user account when failed login attempts exceed limit.",
     "Frozen by {name}": "Frozen by {name}",
+    "Full screen": "Pilna ekr\u0101na re\u017e\u012bms",
     "Gallery": "Gallery",
     "General information": "General information",
     "Generate": "Izveidot",
@@ -493,7 +506,7 @@
     "Handled": "Apstr\u0101d\u0101ts",
     "Help": "Pal\u012bdz\u012bba",
     "Hide": "Sl\u0113pt",
-    "Hide all": "Hide all",
+    "Hide all": "Sl\u0113pt visus stulpeli",
     "Hide properties": "Hide properties",
     "History": "V\u0113sture",
     "History Setting": "V\u0113stures iestat\u012bjumi",
@@ -520,10 +533,10 @@
     "Institutions": "Instit\u016bcija",
     "Internal Link": "Internal Link",
     "Internal Server Error": "Iek\u0161\u0113j\u0101 servera k\u013c\u016bda",
-    "Internal link has been copied to clipboard": "Internal link has been copied to clipboard",
+    "Internal link has been copied to clipboard": "Kop\u0113t iek\u0161\u0113jo linku",
     "Invalid destination path": "Neder\u012bgs m\u0113r\u0137a ce\u013c\u0161",
     "Invalid filename.": "Invalid filename.",
-    "Invalid filter": "Invalid filter",
+    "Invalid filter": "Nepareiza filtr\u0113\u0161anas opcija",
     "Invalid month, should be yyyymm.": "Invalid month, should be yyyymm.",
     "Invalid regular expression": "Invalid regular expression",
     "Invisible": "Invisible",
@@ -548,6 +561,7 @@
     "Last Access": "P\u0113d\u0113j\u0101 piek\u013cuve",
     "Last Login": "P\u0113d\u0113j\u0101 pieteik\u0161an\u0101s",
     "Last Update": "Atjaunots",
+    "Last modification": "P\u0113d\u0113j\u0101s izmai\u0146as",
     "Last modified by": "Last modified by",
     "Last modified time": "Last modified time",
     "Last modifier": "Last modifier",
@@ -561,7 +575,6 @@
     "Library": "Kr\u0101tuve",
     "Library Type": "Bibliot\u0113kas tips",
     "Library does not exist": "Bibliot\u0113ka nepast\u0101v",
-    "Library share permission not found.": "Library share permission not found.",
     "Limits": "Ierobe\u017eojumi",
     "Link": "Saite",
     "Link has been copied to clipboard": "Link has been copied to clipboard",
@@ -572,7 +585,7 @@
     "Load all": "Load all",
     "Loading": "Loading",
     "Loading...": "Iel\u0101de... ",
-    "Location": "Location",
+    "Location": "Lok\u0101cija",
     "Lock": "Blo\u0137\u0113t",
     "Log out": "Iziet",
     "Login": "Login",
@@ -582,7 +595,9 @@
     "Long text": "Long text",
     "Manage group members": "Manage group members",
     "Manage members": "Manage members",
+    "Mark all as read": "P\u0101rbaud\u012bt visas k\u0101 las\u012btas",
     "Mark all read": "Atz\u012bm\u0113t visas izlas\u012btas",
+    "Mark as resolved": "Iz\u012bm\u0113t k\u0101 atrisin\u0101tu",
     "Max": "Max",
     "Max number of members": "Max number of members",
     "Member": "Dal\u012bbnieks",
@@ -631,7 +646,7 @@
     "Name updated": "Name updated",
     "Name(optional)": "V\u0101rds (nav oblig\u0101ti)",
     "Network error": "Network error",
-    "New": "New",
+    "New": "Nou\u017e\u0123\u012bt",
     "New Department": "New Department",
     "New Department Library": "New Department Library",
     "New Excel File": "Jauna Excel datne",
@@ -645,13 +660,12 @@
     "New PowerPoint File": "Jauna PowerPoint datne",
     "New SeaDoc File": "New SeaDoc File",
     "New Sub-department": "New Sub-department",
-    "New Wiki name": "New Wiki name",
     "New Word File": "New Word File",
     "New directories": "Jaunas mapes",
     "New file name": "New file name",
     "New files": "Jauna datne",
     "New folder name": "New folder name",
-    "New page": "New page",
+    "New page": "N\u0101kam\u0101 lapa",
     "New password": "Jauna parole",
     "New password cannot be the same as old password": "New password cannot be the same as old password",
     "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.": "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.",
@@ -660,10 +674,11 @@
     "New view": "New view",
     "Next": "N\u0101kamais",
     "Next (Right arrow key)": "N\u0101kamais (bulti\u0146a pa labi)",
+    "Next modification": "N\u0101kam\u0101s izmai\u0146as",
     "No Admin login logs": "No Admin login logs",
     "No Admin operation logs": "No Admin operation logs",
     "No Wikis": "No Wikis",
-    "No changes": "No changes",
+    "No changes": "Nav izmai\u0146\u0101m",
     "No collaborators": "No collaborators",
     "No collaborators available": "No collaborators available",
     "No comment yet.": "Nav koment\u0101ru.",
@@ -673,7 +688,7 @@
     "No file": "No file",
     "No file access logs": "No file access logs",
     "No file update logs": "No file update logs",
-    "No filters": "No filters",
+    "No filters": "Nav pievienotas filtr\u0113\u0161anas opcijas",
     "No folders shared": "No folders shared",
     "No groupings applied to this view.": "No groupings applied to this view.",
     "No groups": "Nav grupas",
@@ -698,11 +713,12 @@
     "No properties available to be hidden": "No properties available to be hidden",
     "No record": "No record",
     "No result": "Nav rezult\u0101ta",
-    "No results": "No results",
+    "No results": "Nav atrast\u0101s rezult\u0101tas",
     "No results matching": "No results matching",
     "No share links": "No share links",
+    "No sorts": "Nav r\u0101d\u012b\u0161anas opcijas",
     "No sync errors": "Nav sinhroniz\u0101cijas k\u013c\u016bdas",
-    "No tags": "No tags",
+    "No tags": "Nav atz\u012bm\u0113m",
     "No terms and conditions": "No terms and conditions",
     "No upload links": "No upload links",
     "No version history": "No version history",
@@ -747,14 +763,14 @@
     "Open folder": "Open folder",
     "Open folder in new tab": "Open folder in new tab",
     "Open in new tab": "Open in new tab",
-    "Open parent folder": "Open parent folder",
+    "Open parent folder": "Atv\u0113rt vec\u0101ka mapes",
     "Open via Client": "Atv\u0113rt ar klientu",
     "Operation": "Darb\u012bbas",
     "Operation succeeded.": "Darb\u012bba veiksm\u012bga",
     "Operations": "Darb\u012bbas",
     "Optional": "Optional",
     "Options imported": "Options imported",
-    "Or": "Or",
+    "Or": "Vai",
     "Organization": "Organiz\u0101cija",
     "Organization Admin": "Organiz\u0101cijas administrators",
     "Organizations": "Organiz\u0101cijas",
@@ -764,6 +780,7 @@
     "Others": "Others",
     "Out of quota.": "P\u0101rsniegts apjoms",
     "Outdated": "Outdated",
+    "Outline": "Izskait\u013cis",
     "Owned Libraries": "Owned Libraries",
     "Owner": "\u012apa\u0161nieks",
     "Owner can use admin panel in an organization, must be a new account.": "Owner can use admin panel in an organization, must be a new account.",
@@ -801,7 +818,7 @@
     "Please choose an image file.": "Please choose an image file.",
     "Please enter 1 or more character": "L\u016bdzu, ievadiet 1 vai vair\u0101k rakstz\u012bmes",
     "Please enter a new password": "L\u016bdzu, ievadiet jaunu paroli",
-    "Please enter a non-negative integer": "Please enter a non-negative integer",
+    "Please enter a non-negative integer": "L\u016bdzu, ievadiet nepiecie\u0161am\u0101s dienas",
     "Please enter a password.": "Please enter a password.",
     "Please enter a positive integer": "Please enter a positive integer",
     "Please enter an integer bigger than 1 as number of links.": "Please enter an integer bigger than 1 as number of links.",
@@ -817,19 +834,20 @@
     "Please select an expiration time": "Please select an expiration time",
     "Please upload no more than {maxFiles} files at a time.": "Please upload no more than {maxFiles} files at a time.",
     "Preset hide properties": "Preset hide properties",
-    "Preview and download": "Preview and download",
+    "Preview and download": "P\u0101rskat\u012bt un lejupiel\u0101d\u0113t",
     "Preview online": "Preview online",
-    "Preview only": "Preview only",
+    "Preview only": "P\u0101rskat\u012bt tikai",
     "Previous": "Iepriek\u0161\u0113jais",
     "Previous (Left arrow key)": "Iepriek\u0161\u0113jais (bulti\u0146a pa kreisi)",
-    "Print": "Print",
+    "Print": "Noprint\u0113t",
     "Professional Edition": "Profesion\u0101lais izdevums",
     "Profile": "Profils",
     "Profile Setting": "Profila iestat\u012bjumi",
     "Properties": "Properties",
     "Property name": "Property name",
-    "Publish": "Publish",
+    "Publish": "Publ\u0113t",
     "Publish Wiki": "Publish Wiki",
+    "Published": "Public\u0113ts",
     "Quota": "Quota",
     "Quota is invalid.": "Quota is invalid.",
     "Rate": "Rate",
@@ -843,7 +861,7 @@
     "Really want to delete your account?": "Tie\u0161\u0101m dz\u0113st kontu?",
     "Really want to leave this group?": "Really want to leave this group?",
     "Recognizing portraits. Please refresh the page later.": "Recognizing portraits. Please refresh the page later.",
-    "Refresh": "Refresh",
+    "Refresh": "Atjaunot",
     "Remove": "Aizv\u0101kt",
     "Rename": "P\u0101rsaukt",
     "Rename Department": "Rename Department",
@@ -873,6 +891,7 @@
     "Reset library password": "Reset library password",
     "ResetPwd": "Atstat\u012bt",
     "Resetting user's password, please wait for a moment.": "Resetting user's password, please wait for a moment.",
+    "Resolved comments": "Pabeigti koment\u0101ri",
     "Restore": "Atjaunot",
     "Restore Library": "Atjaunot bibliot\u0113ku",
     "Restored file": "Restored file",
@@ -880,33 +899,35 @@
     "Restored library": "Restored library",
     "Restored {name}": "Restored {name}",
     "Restored {name} and {n} other items": "Restored {name} and {n} other items",
+    "Resubmit": "P\u0101rbaud\u012bt v\u0113lreiz",
     "Result": "Rezult\u0101ts",
     "Revoke Access": "Revoke Access",
     "Revoke Admin": "Anul\u0113t administratoru",
     "Role": "Loma",
     "SAML config": "SAML config",
     "SAML config updated": "SAML config updated",
-    "Save": "Save",
+    "Save": "Saglab\u0101t",
     "Save Selected Items": "Save Selected Items",
     "Save to:": "Save to:",
     "Saving...": "Saglab\u0101...",
     "Scan the QR code to view the shared content directly": "Scan the QR code to view the shared content directly",
     "SeaTable integration": "SeaTable integration",
     "Seafile": "Seafile",
-    "Search": "Search",
+    "Search": "Mekl\u0113t",
     "Search Groups": "Search Groups",
     "Search Libraries": "Search Libraries",
     "Search Organizations": "Search Organizations",
     "Search Users": "Search Users",
-    "Search collaborator": "Search collaborator",
+    "Search collaborator": "Mekl\u0113t kolabor\u0101tora",
     "Search collaborators": "Search collaborators",
+    "Search department": "Mekl\u0113t departamentu",
     "Search files": "Search files",
     "Search files in this library": "Mekl\u0113t datnes bibliot\u0113k\u0101",
     "Search groups": "Mekl\u0113t grupas",
     "Search groups by name": "Search groups by name",
     "Search libraries by name or ID": "Search libraries by name or ID",
     "Search libraries by owner": "Search libraries by owner",
-    "Search option": "Search option",
+    "Search option": "Mekl\u0113t opciju",
     "Search organizations": "Search organizations",
     "Search property": "Search property",
     "Search users": "Search users",
@@ -918,10 +939,10 @@
     "Select a user": "Select a user",
     "Select a user as admin": "Select a user as admin",
     "Select all": "Select all",
-    "Select an option": "Select an option",
+    "Select an option": "Izv\u0113lieties opciju",
     "Select collaborators": "Select collaborators",
     "Select libraries to share": "Atlas\u012bt koplieto\u0161anas bibliot\u0113kas ",
-    "Select option(s)": "Select option(s)",
+    "Select option(s)": "Izv\u0113lieties opciju(us)",
     "Select up to 50 files": "Select up to 50 files",
     "Send": "S\u016bt\u012bt",
     "Send activation Email after user registration.": "Send activation Email after user registration.",
@@ -940,6 +961,7 @@
     "Set WebDAV Password": "Set WebDAV Password",
     "Set max number of members": "Set max number of members",
     "Set password": "Set password",
+    "Set permission": "Iestat\u012bt at\u013caujas",
     "Set permission of {placeholder}": "Set permission of {placeholder}",
     "Set to current": "Iestat\u012bt pa\u0161reiz\u0113jo",
     "Set user contact email": "Set user contact email",
@@ -951,7 +973,7 @@
     "Share": "Dal\u012bties",
     "Share Admin": "Koplieto\u0161an\u0101",
     "Share From": "Koplietojums no ",
-    "Share Link": "Share Link",
+    "Share Link": "Dal\u012bties saiti",
     "Share Links": "Koplieto\u0161anas saites",
     "Share To": "Dal\u012bts ar",
     "Share To:": "Share To:",
@@ -970,14 +992,14 @@
     "Shared with me": "Man koplietot\u0101s ",
     "Show": "R\u0101d\u012bt",
     "Show Codes": "R\u0101d\u012bt kodu",
-    "Show all": "Show all",
+    "Show all": "Par\u0101d\u012bt visus stulpeli",
     "Show changes": "Show changes",
     "Side Nav Menu": "S\u0101nu navig\u0101cijas izv\u0113lne",
     "Single select": "Single select",
     "Site name used in email sending": "Site name used in email sending",
     "Site title shown in a browser tab": "Site title shown in a browser tab",
     "Size": "Izm\u0113rs ",
-    "Sort": "Sort",
+    "Sort": "R\u0101d\u012bt p\u0113c",
     "Sort ascending": "Sort ascending",
     "Sort descending": "Sort descending",
     "Space Used": "Izlietots",
@@ -991,7 +1013,7 @@
     "Storage": "Kr\u0101tuve",
     "Storage Backend": "Storage Backend",
     "Storage Used": "Kr\u0101tuves izlietojums",
-    "Style": "Style",
+    "Style": "Stilijs",
     "Submit": "Pielietot",
     "Success": "Veiksm\u012bgi",
     "Successfully added label(s) for library {placeholder}": "Successfully added label(s) for library {placeholder}",
@@ -1038,10 +1060,10 @@
     "Successfully unlinked the device.": "Successfully unlinked the device.",
     "Successfully unshared {name}": "Successfully unshared {name}",
     "Successfully unstarred {library_name_placeholder}.": "Successfully unstarred {library_name_placeholder}.",
-    "Suggestion": "Suggestion",
+    "Suggestion": "Sugestija",
     "Switch sort mode": "Switch sort mode",
-    "Switch to plain text editor": "Switch to plain text editor",
-    "Switch to rich text editor": "Switch to rich text editor",
+    "Switch to plain text editor": "P\u0101rsl\u0113gt uz vienk\u0101r\u0161u teksta redaktoru",
+    "Switch to rich text editor": "P\u0101rsl\u0113gt uz pl\u0101no teksta redaktoru",
     "Switch view mode": "Switch view mode",
     "Sync": "Sync",
     "Sync Download": "Sync Download",
@@ -1051,9 +1073,9 @@
     "System Info": "Sist\u0113mas info",
     "System settings updated": "System settings updated",
     "Table": "Tabula",
-    "Tag not found": "Tag not found",
+    "Tag not found": "Taga nav atrasts",
     "Tagged Files": "Tagged Files",
-    "Tags": "Tags",
+    "Tags": "Atz\u012bmes",
     "Team name": "Team name",
     "Template": "\u0160ablons",
     "Terms": "Terms",
@@ -1087,7 +1109,7 @@
     "There is another option with this name": "There is another option with this name",
     "There is another property with this name": "There is another property with this name",
     "There is no information to display.": "There is no information to display.",
-    "This file has been updated.": "This file has been updated.",
+    "This file has been updated.": "Fails ir atjaunots.",
     "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).": "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).",
     "This folder has no content at this time.": "This folder has no content at this time.",
     "This is a special group representing a department.": "This is a special group representing a department.",
@@ -1148,13 +1170,14 @@
     "Unlink": "Atsaist\u012bt",
     "Unlink device": "Atsaist\u012bt\u0101s ier\u012bces",
     "Unlock": "Atblo\u0137\u0113t",
+    "Unresolved comments": "Neapstr\u0101d\u0101ti koment\u0101ri",
     "Unselect": "Unselect",
     "Unshare": "Liegt pieeju",
     "Unshare Library": "Atcelt pieejas kr\u0101tuvei",
     "Unstar": "Bez zvaigzn\u012btes",
     "Untitled": "Untitled",
     "Unwatch File Changes": "Unwatch File Changes",
-    "Up": "Up",
+    "Up": "Aug\u0161\u0101",
     "Update": "Atjaunot",
     "Update Terms and Conditions": "Atjaunot noteikumus un nosac\u012bjumus",
     "Update password": "Update password",
@@ -1246,12 +1269,12 @@
     "ZIP": "ZIP",
     "all": "visi",
     "all members": "visi dal\u012bbnieki",
-    "contains": "contains",
+    "contains": "Atbilst",
     "days": "dienas",
     "deleted": "deleted",
     "deleted option": "deleted option",
     "details": "details",
-    "does not contain": "does not contain",
+    "does not contain": "Nekatram atbilst",
     "email is required": "email is required",
     "freezed": "freezed",
     "has all of...": "has all of...",
@@ -1259,17 +1282,17 @@
     "has none of...": "has none of...",
     "icon": "ikona",
     "in all libraries": "in all libraries",
-    "include the current user": "include the current user",
-    "is": "is",
+    "include the current user": "Izmantojiet pa\u0161reiz\u0113jo lietot\u0101ju",
+    "is": "Liekas",
     "is after...": "is after...",
     "is any of...": "is any of...",
     "is before...": "is before...",
-    "is current user's ID": "is current user's ID",
-    "is empty": "is empty",
+    "is current user's ID": "Liekas pa\u0161reiz\u0113j\u0101 lietot\u0101ja ID",
+    "is empty": "Liekas tuk\u0161a",
     "is exactly...": "is exactly...",
     "is none of...": "is none of...",
-    "is not": "is not",
-    "is not empty": "is not empty",
+    "is not": "Nekatram liekas",
+    "is not empty": "Nekatram liekas tuk\u0161a",
     "is on or after...": "is on or after...",
     "is on or before...": "is on or before...",
     "is within...": "is within...",
@@ -1285,7 +1308,7 @@
     "s": "s",
     "selected": "selected",
     "show more": "show more",
-    "sorts": "sorts",
+    "sorts": "R\u0101d\u012b\u0161anas opcijas",
     "starred": "zvaig\u017e\u0146otas",
     "successfully added user %s.": "successfully added user %s.",
     "successfully sent email to %s.": "successfully sent email to %s.",
@@ -1297,6 +1320,7 @@
     "xxx records selected": "xxx records selected",
     "xxx rows are copied.": "xxx rows are copied.",
     "you can also press \u2190 ": "var spiest ar\u012b  \u2190 ",
+    "you can also press \u2192": "you can also press \u2192",
     "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
     "{file} and {n} other files": "{file} and {n} other files",
     "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
