@@ -36,7 +36,11 @@
     "1 week ago": "1 tu\u1ea7n tr\u01b0\u1edbc",
     "3 days ago": "3 ng\u00e0y tr\u01b0\u1edbc",
     "A file is being uploaded. Are you sure you want to leave this page?": "A file is being uploaded. Are you sure you want to leave this page?",
+    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
+    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
     "A file with the same name already exists in this folder.": "M\u1ed9t file tr\u00f9ng t\u00ean \u0111\u00e3 t\u1ed3n t\u1ea1i trong th\u01b0 m\u1ee5c n\u00e0y.",
+    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
+    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
     "API Token": "API Token",
     "API token is copied to the clipboard.": "API token is copied to the clipboard.",
     "About Us": "Li\u00ean h\u1ec7",
@@ -555,7 +559,6 @@
     "Library": "Th\u01b0 vi\u1ec7n",
     "Library Type": "Library Type",
     "Library does not exist": "Th\u01b0 vi\u1ec7n kh\u00f4ng t\u1ed3n t\u1ea1i",
-    "Library share permission not found.": "Library share permission not found.",
     "Limits": "Gi\u1edbi h\u1ea1n",
     "Link": "Li\u00ean k\u1ebft",
     "Link has been copied to clipboard": "Link has been copied to clipboard",
@@ -641,7 +644,6 @@
     "New PowerPoint File": "New PowerPoint File",
     "New SeaDoc File": "New SeaDoc File",
     "New Sub-department": "New Sub-department",
-    "New Wiki name": "New Wiki name",
     "New Word File": "New Word File",
     "New directories": "Th\u01b0 m\u1ee5c m\u1edbi",
     "New file name": "New file name",
@@ -1291,6 +1293,7 @@
     "xxx records": "xxx records",
     "xxx records selected": "xxx records selected",
     "xxx rows are copied.": "xxx rows are copied.",
+    "you can also press \u2192": "you can also press \u2192",
     "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
     "{file} and {n} other files": "{file} and {n} other files",
     "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
